@@ -144,8 +144,8 @@ setMethod(
           if (create == TRUE) {
             lapply(path[!dirsThatExist[!isExistingFile]], function(pth) {
               dir.create(file.path(pth),
-                recursive = TRUE,
-                showWarnings = FALSE
+                         recursive = TRUE,
+                         showWarnings = FALSE
               )
             })
           } else {
@@ -203,12 +203,15 @@ setMethod(
 #' @keywords internal
 .rndstr <- function(n = 1, len = 8) {
   unlist(lapply(character(n), function(x) {
-    x <-
-      paste0(sample(
-        c(0:9, letters, LETTERS),
-        size = len,
-        replace = TRUE
-      ), collapse = "")
+    a <- c(0:9, letters, LETTERS)
+    b <- sample(a, size = len, replace = TRUE)
+    paste0(b, collapse = "")
+    # x <-
+    #   paste0(sample(
+    #     c(0:9, letters, LETTERS),
+    #     size = len,
+    #     replace = TRUE
+    #   ), collapse = "")
   }))
 }
 
@@ -271,6 +274,12 @@ tempdir2 <- function(sub = "",
   np
 }
 
+tempdir3 <- function(sub = "Require") {
+  nd <- tempdir() |> file.path(sub, basename(tempfile("tmpdir")))
+  made <- dir.create(nd, showWarnings = FALSE, recursive = TRUE)
+  nd
+}
+
 #' Make a temporary subfile in a temporary (sub-)directory
 #'
 #' @param ... passed to `tempfile`, e.g., `fileext`
@@ -477,8 +486,8 @@ messageVerboseCounter <-
     messWithPrePost <- paste0(pre, mess, post)
     if (counter == minCounter) {
       messageVerbose(rep(" ", numCharsNeeded),
-        verbose = verbose,
-        verboseLevel = verboseLevel
+                     verbose = verbose,
+                     verboseLevel = verboseLevel
       )
     }
     messageVerbose(
@@ -573,17 +582,21 @@ SysInfo <-
   Sys.info() # do this on load; nothing can change, so repeated calls are a waste
 
 .setupExample <- function() {
-  options(
+  l <- list()
+  l$opts <- options(
     Ncpus = 2L,
     Require.RequirePkgCache = FALSE
   ) ## TODO: use e.g., `tempdir2("examples")`
+  # l$libOrig <- setLibPaths(tempdir3())
+  l
 }
 
 .cleanup <- function(opts = list()) {
+  unlink(file.path(tempdir(), "Require"), recursive = TRUE)
   unlink(Require::tempdir2(create = FALSE), recursive = TRUE)
-  clearRequirePackageCache(
+  cacheClearPackages(
     ask = FALSE,
-    Rversion = rversion(),
+    Rversion = versionMajorMinor(),
     verbose = FALSE
   )
   # It appears that _R_CHECK_THINGS_IN_OTHER_DIRS_ detects both the R and the Require
@@ -602,7 +615,8 @@ SysInfo <-
   if (length(filesOuter) == 1 && length(filesOneIn) <= 1) {
     unlink(filesOuter, recursive = TRUE)
   }
-  options(opts)
+  # setLibPaths(opts$libOrig)
+  options(opts$opts)
 }
 
 #' @importFrom utils packageDescription
@@ -624,8 +638,9 @@ SysInfo <-
 
 doCranCacheCheck <- function(localFiles, verbose = getOption("Require.verbose")) {
   if (getOption("Require.useCranCache", FALSE)) {
-    if (is.null(.pkgEnv[["crancacheCheck"]])) {
-      .pkgEnv[["crancacheCheck"]] <- TRUE
+    pe <- pkgEnv()
+    if (is.null(pe[["crancacheCheck"]])) {
+      pe[["crancacheCheck"]] <- TRUE
       crancache <- crancacheFolder()
       if (dir.exists(crancache)) {
         ccFiles <- dir(crancache, full.names = TRUE, recursive = TRUE)
@@ -633,12 +648,12 @@ doCranCacheCheck <- function(localFiles, verbose = getOption("Require.verbose"))
         alreadyThere <- basename(ccFiles) %in% basename(localFiles)
         if (any(!alreadyThere)) {
           ccFiles <- ccFiles[!alreadyThere]
-          toFiles <- file.path(getOptionRPackageCache(), basename(ccFiles))
+          toFiles <- file.path(cacheGetOptionCachePkgDir(), basename(ccFiles))
           linked <- linkOrCopy(ccFiles, toFiles)
           messageVerbose(blue("crancache had some packages; creating link or copy in Require Cache"),
-            verbose = verbose, verboseLevel = 1
+                         verbose = verbose, verboseLevel = 1
           )
-          localFiles <- dir(getOptionRPackageCache(), full.names = TRUE)
+          localFiles <- dir(cacheGetOptionCachePkgDir(), full.names = TRUE)
         }
       }
     }
@@ -647,86 +662,38 @@ doCranCacheCheck <- function(localFiles, verbose = getOption("Require.verbose"))
 }
 
 
+# library(rversions)
+# dput(tail(r_versions(), 12))
 rversionHistory <- as.data.table(
   structure(list(
-    version = c(
-      "0.60", "0.61", "0.61.1", "0.61.2",
-      "0.61.3", "0.62", "0.62.1", "0.62.2", "0.62.3", "0.62.4", "0.63",
-      "0.63.1", "0.63.2", "0.63.3", "0.64", "0.64.1", "0.64.2", "0.65",
-      "0.65.1", "0.90", "0.90.1", "0.99", "1.0", "1.0.1", "1.1", "1.1.1",
-      "1.2", "1.2.1", "1.2.2", "1.2.3", "1.3", "1.3.1", "1.4", "1.4.1",
-      "1.5.0", "1.5.1", "1.6.0", "1.6.1", "1.6.2", "1.7.0", "1.7.1",
-      "1.8.0", "1.8.1", "1.9.0", "1.9.1", "2.0.0", "2.0.1", "2.1.0",
-      "2.1.1", "2.2.0", "2.2.1", "2.3.0", "2.3.1", "2.4.0", "2.4.1",
-      "2.5.0", "2.5.1", "2.6.0", "2.6.1", "2.6.2", "2.7.0", "2.7.1",
-      "2.7.2", "2.8.0", "2.8.1", "2.9.0", "2.9.1", "2.9.2", "2.10.0",
-      "2.10.1", "2.11.0", "2.11.1", "2.12.0", "2.12.1", "2.12.2", "2.13.0",
-      "2.13.1", "2.13.2", "2.14.0", "2.14.1", "2.14.2", "2.15.0", "2.15.1",
-      "2.15.2", "2.15.3", "3.0.0", "3.0.1", "3.0.2", "3.0.3", "3.1.0",
-      "3.1.1", "3.1.2", "3.1.3", "3.2.0", "3.2.1", "3.2.2", "3.2.3",
-      "3.2.4", "3.2.5", "3.3.0", "3.3.1", "3.3.2", "3.3.3", "3.4.0",
-      "3.4.1", "3.4.2", "3.4.3", "3.4.4", "3.5.0", "3.5.1", "3.5.2",
-      "3.5.3", "3.6.0", "3.6.1", "3.6.2", "3.6.3", "4.0.0", "4.0.1",
-      "4.0.2", "4.0.3", "4.0.4", "4.0.5", "4.1.0", "4.1.1", "4.1.2",
-      "4.1.3", "4.2.0", "4.2.1", "4.2.2"
-    ),
-    date = structure(
-      c(
-        881225278,
-        882709762, 884392315, 889903555, 894095897, 897828980, 897862405,
-        900069225, 904294939, 909144521, 910967839, 912776788, 916059350,
-        920644034, 923491181, 926083543, 930918195, 935749769, 939211984,
-        943273514, 945260947, 949922690, 951814523, 955701858, 961058601,
-        966329658, 976875565, 979553881, 983191405, 988284587, 993206462,
-        999261952, 1008756894, 1012391855, 1020074486, 1024312833, 1033466791,
-        1036146797, 1042212874, 1050497887, 1055757279, 1065611639, 1069416021,
-        1081766198, 1087816179, 1096899878, 1100528190, 1113863193, 1119259633,
-        1128594134, 1135074921, 1145875040, 1149150333, 1159870504, 1166435363,
-        1177407703, 1183029426, 1191402173, 1196086444, 1202469005, 1208850329,
-        1214207072, 1219654436, 1224494641, 1229936597, 1239957168, 1246018257,
-        1251102154, 1256547742, 1260786504, 1271923881, 1275293425, 1287132117,
-        1292490724, 1298632039, 1302683487, 1310117828, 1317366356, 1320048549,
-        1324541418, 1330503010, 1333091765, 1340348984, 1351235476, 1362126509,
-        1364973156, 1368688293, 1380093069, 1394093553, 1397113870, 1404976269,
-        1414743092, 1425888740, 1429168413, 1434611704, 1439536398, 1449735188,
-        1457597745, 1460649578, 1462259608, 1466493698, 1477901595, 1488788191,
-        1492758885, 1498806251, 1506582275, 1512029105, 1521101067, 1524467078,
-        1530515071, 1545293080, 1552291489, 1556262303, 1562310303, 1576137903,
-        1582963516, 1587711934, 1591427116, 1592809519, 1602313524, 1613376313,
-        1617174315, 1621321522, 1628579106, 1635753912, 1646899538, 1650611141,
-        1655967933, 1667203554
-      ),
-      class = c("POSIXct", "POSIXt"), tzone = "UTC"
-    ),
-    nickname = c(
-      NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
-      NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
-      NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
-      NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
-      NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
-      NA, NA, NA, NA, NA, NA, NA, "Great Pumpkin", "December Snowflakes",
-      "Gift-Getting Season", "Easter Beagle", "Roasted Marshmallows",
-      "Trick or Treat", "Security Blanket", "Masked Marvel", "Good Sport",
-      "Frisbee Sailing", "Warm Puppy", "Spring Dance", "Sock it to Me",
-      "Pumpkin Helmet", "Smooth Sidewalk", "Full of Ingredients",
-      "World-Famous Astronaut", "Fire Safety", "Wooden Christmas-Tree",
-      "Very Secure Dishes", "Very, Very Secure Dishes", "Supposedly Educational",
-      "Bug in Your Hair", "Sincere Pumpkin Patch", "Another Canoe",
-      "You Stupid Darkness", "Single Candle", "Short Summer", "Kite-Eating Tree",
-      "Someone to Lean On", "Joy in Playing", "Feather Spray",
-      "Eggshell Igloo", "Great Truth", "Planting of a Tree", "Action of the Toes",
-      "Dark and Stormy Night", "Holding the Windsock", "Arbor Day",
-      "See Things Now", "Taking Off Again", "Bunny-Wunnies Freak Out",
-      "Lost Library Book", "Shake and Throw", "Camp Pontanezen",
-      "Kick Things", "Bird Hippie", "One Push-Up", "Vigorous Calisthenics",
-      "Funny-Looking Kid", "Innocent and Trusting"
-    )
-  ), row.names = c(
-    NA,
-    -129L
-  ), class = "data.frame")
+    version = c("4.0.5", "4.1.0", "4.1.1", "4.1.2",
+                "4.1.3", "4.2.0", "4.2.1", "4.2.2", "4.2.3", "4.3.0", "4.3.1",
+                "4.3.2"),
+    date = structure(c(1617174315, 1621321522, 1628579106,
+                       1635753912, 1646899538, 1650611141, 1655967933, 1667203554, 1678867561,
+                       1682060774, 1686899167, 1698739662), class = c("POSIXct", "POSIXt"
+                       ), tzone = "UTC"),
+    nickname = c("Shake and Throw", "Camp Pontanezen",
+                 "Kick Things", "Bird Hippie", "One Push-Up", "Vigorous Calisthenics",
+                 "Funny-Looking Kid", "Innocent and Trusting", "Shortstop Beagle",
+                 "Already Tomorrow", "Beagle Scouts", "Eye Holes")),
+    row.names = 122:133, class = "data.frame")
 )
 
 crancacheFolder <- function() {
   crancache <- file.path(dirname(dirname(tools::R_user_dir("Require", "cache"))), "R-crancache")
 }
+
+
+colr <- function(..., digit = 32) paste0("\033[", digit, "m", paste0(...), "\033[39m")
+purple <- function(...) colr(..., digit = "38;5;129m")
+black <- function(...) colr(..., digit = 30)
+green2 <- function(...) colr(..., digit = 38)
+cyan <- function(...) colr(..., digit = 29)
+red <- function(...) colr(..., digit = 31)
+green <- function(...) colr(..., digit = 32)
+yellow <- function(...) colr(..., digit = 33)
+blue <- function(...) colr(..., digit = 34)
+turquoise <- function(...) colr(..., digit = 36)
+greyLight <- function(...) colr(..., digit = 90)
+
